@@ -316,9 +316,9 @@ class Connection():
 
     def __format_object_insert_query__(self, obj):
         table =  self._inflector.tableize(obj.__class__.__name__)
-        keys = ', '.join([key for key in obj.__metadata__['data']])
-        values = ', '.join([f'%({key})s' for key in obj.__metadata__['data']])
-        on_keys = ', '.join([f"{key}=%({key})s" for key in obj.__metadata__['data']])
+        keys = ', '.join([key for key, value in obj.__metadata__['data'].items() if value])
+        values = ', '.join([f'%({key})s' for key, value in obj.__metadata__['data'].items() if value])
+        on_keys = ', '.join([f"{key}=%({key})s" for key, value in obj.__metadata__['data'].items() if value])
         return f"INSERT INTO {table} ({keys}) VALUES ({values}) ON DUPLICATE KEY UPDATE {on_keys}"
 
     def select(self, *fields):
@@ -452,7 +452,7 @@ class Connection():
         Debug("Saving Object")
         def do_object(_obj):
             _add_query = self.__format_object_insert_query__(_obj)
-            _last_row_id = self._conn.save(_add_query, _obj.__metadata__['data'])
+            _last_row_id = self._conn.save(_add_query, {key:value for key, value in _obj.__metadata__['data'].items() if value})
             if _last_row_id:
                 _pk_key = obj.__metadata__['pk'][0]
                 _obj.__setattr__(_pk_key, _last_row_id)
@@ -483,6 +483,15 @@ class Connection():
                         do_object(sub_item)
                         do_relacional(rel, obj, sub_item)
 
+
+    def set(self, field, value):
+        _where = [w for w in self._where if self.__is_clause_table__(w)] if self._where else []
+        _where = f" WHERE ({' AND '.join(_where)})" if len(_where) > 0 else ''
+        _orwhere = ''.join([c for c in [f" OR ({' AND '.join([w for w in conditions if self.__is_clause_table__(w)])})" for block, conditions in self._orwhere.items()] if c.strip() != 'OR ()']) if self._orwhere else ''
+        query = f"UPDATE {self._table} SET {field}='{value}' {_where}{_orwhere}"
+        self._conn.save(query, {})
+        self._conn.commit()
+
     def save(self):
 
         # DELETE OBJECTS
